<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Mode d&apos;avió activat</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Mode d&apos;avió desactivat</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Inhabilita</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Habilita</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode d&apos;avió</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Configuració del mode avió</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode d&apos;avió</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Els meus dispositius</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Configuració del Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Apagat</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation>Desactiveu primer el [Airplane Mode](#) si voleu connectar-vos per Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Engega</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Configuració del Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connectat</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Es connecta...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Apagat</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Connectat amb %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No connectat</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desactivat</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Brillantor</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Configuració de la pantalla</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Configuració de la pantalla</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Brillantor</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>dg.</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>dl.</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>dt.</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>dc.</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>dj.</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>dv.</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>ds.</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Afegeix una disposició de teclat</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dia i hora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 hores</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 hores</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Configuració de l&apos;hora</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Obre el calendari</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Dilluns</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dimarts</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Dimecres</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Dijous</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Divendres</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Dissabte</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Diumenge</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>dilluns</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>dimarts</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>dimecres</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>dijous</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>divendres</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>dissabte</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>diumenge</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Altres dispositius</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Mode de no molestar</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Configuració del mode de no molestar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Inhabilita</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Habilita</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Mode de no molestar habilitat</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Mode de no molestar inhabilitat</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Mode de no molestar</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Confort ocular</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Confort ocular habilitat</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Confort ocular inhabilitat</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Configuració de la pantalla</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Confort ocular</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Activat</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desactivat</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Clar</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Fosc</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Desactiva el confort ocular</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Activa el confort ocular</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Configuració de la pantalla</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Tema: clar</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Tema: fosc</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Tema: automàtic</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Efecte visual</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Clar</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Fosc</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>No hi ha cap missatge.</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Configuració de les notificacions</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificacions</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Desactiva el mode de No emprenyar</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Activa el mode de No emprenyar</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Notificació</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Abord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Alt rendiment</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Equilibrat</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Estalviador d&apos;energia</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Equilibratge del rendiment</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Configuració de l&apos;energia</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacitat: %1, %2 min restants</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacitat: %1, %2 h %3 min restants</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Es carrega %1, %2 min per completar-la.</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Es carrega %1, %2 h %3 min per completar-la.</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacitat %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Carregant: %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacitat %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacitat: 1%, completament carregada</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Capacitat: 1%, no es carrega</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Bateria</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Carregant. Es calcula l&apos;estimació del temps de càrrega...</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Es calcula el temps d&apos;ús restant...</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>Temps restant: %1 min</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>Temps restant: %1 h i %2 min</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>No es carrega</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Carregada</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Es carrega. %1 min per completar-la.</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Es carrega. %1 h i %2 min per completar-la.</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Capacitat: %1, %2 h restants</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>Temps restant: %1 h</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Es carrega %1, %2 h per completar-la.</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Es carrega. %1 h per completar-la.</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Configuració de l&apos;energia</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn-te</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloca</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Surt de la sessió</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Configuració de l&apos;energia</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia&apos;t</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Actualitza i atura</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Actualitza i reinicia</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Canvia d&apos;usuari</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <source>y</source>
        <translation>any</translation>
    </message>
    <message>
        <source>m</source>
        <translation>mes</translation>
    </message>
    <message>
        <source>d</source>
        <translation>dia</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Dilluns</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dimarts</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Dimecres</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Dijous</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Divendres</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Dissabte</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Diumenge</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Gen.</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Febr.</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Març</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Abr.</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Maig</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Juny</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Jul.</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Ag.</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Set.</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Oct.</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Nov.</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Des.</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Obre el calendari</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>dilluns</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>dimarts</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>dimecres</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>dijous</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>divendres</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>dissabte</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>diumenge</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volum</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configuració del so</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>So</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Activa el so</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silencia</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configuració del so</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Sense dispositius de sortida</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volum: %1</translation>
    </message>
</context>
</TS>